!----------------
PROGRAM EXAMPLE11
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Parameters.
INTEGER, PARAMETER :: NTEMPERATURES = 9

! . Scalars.
INTEGER            :: I
REAL ( KIND = DP ) :: EBOAT, ECHAIR

! . The temperature array.
REAL ( KIND = DP ), DIMENSION(1:NTEMPERATURES)     :: K, T
REAL ( KIND = DP ), DIMENSION(1:7,1:NTEMPERATURES) :: RESULTS_BOAT, RESULTS_CHAIR

! . Print out the header.
CALL DYNAMO_HEADER

! . Fill the temperature array (this is needed to avoid a PGF90 compiler error).
DO I = 1,NTEMPERATURES ; T(I) = 100.0_DP * REAL ( I, DP ) ; END DO

! . Construct the system file for cyclohexane.
CALL MM_SYSTEM_READ ( "cyclohexane.sys_bin" )

! . Read in the coordinates of the chair form.
CALL COORDINATES_READ ( "../data/cyclohexane_chair.crd" )

! . Calculate the energy and its derivatives.
CALL HESSIAN ; ECHAIR = ETOTAL

! . Calculate the frequencies.
CALL NORMAL_MODE_FREQUENCIES ( HESSIAN = ATMHES, MODIFY = "PROJECT" )

! . Calculate the thermodynamic quantities for the chair form.
CALL THERMODYNAMICS ( T, RESULTS_CHAIR, 6, 1.0_DP, .TRUE. )

! . Read in the coordinates of the boat form.
CALL COORDINATES_READ ( "../data/cyclohexane_boat.crd" )

! . Calculate the energy and its derivatives.
CALL HESSIAN ; EBOAT = ETOTAL

! . Calculate the frequencies.
CALL NORMAL_MODE_FREQUENCIES ( HESSIAN = ATMHES, MODIFY = "PROJECT" )

! . Calculate the thermodynamic quantities for the chair form.
CALL THERMODYNAMICS ( T, RESULTS_BOAT, 4, 1.0_DP, .TRUE. )

! . Calculate the equilibrium constants.
K = EXP ( - 1.0E+3_DP * ( RESULTS_BOAT(4,1:NTEMPERATURES) - RESULTS_CHAIR(4,1:NTEMPERATURES) + EBOAT - ECHAIR ) / &
        ( NAVOGADRO * KBOLTZ * T ) )

! . Write out the results.
WRITE ( OUTPUT, "(/A)" ) "Equilibrium constants (chair -> boat):"
WRITE ( OUTPUT, "(/9X,A,15X,A)" ) "Temperature", "Log K"
WRITE ( OUTPUT, "(F20.4,G20.6)" ) ( T(I), LOG10 ( K(I) ), I = 1,NTEMPERATURES )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE11
