!----------------
PROGRAM EXAMPLE13
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local scalars.
INTEGER            :: I, NFRAMES
REAL ( KIND = DP ) :: AVERAGE, RMSDEV

! . Local arrays.
INTEGER,                         DIMENSION(1:4,1:2) :: LIST
REAL ( KIND = DP ), ALLOCATABLE, DIMENSION(:,:)     :: VALUES

! . Local types.
TYPE(DCD_TYPE) :: TRAJECTORY

! . Print out the header.
CALL DYNAMO_HEADER

! . Read in the system file.
CALL MM_SYSTEM_READ ( "bALA.sys_bin" )

! . Initialize the dihedral list array.
LIST(1,1) =  5 ; LIST(2,1) =  7 ; LIST(3,1) =  9 ; LIST(4,1) = 15
LIST(1,2) =  7 ; LIST(2,2) =  9 ; LIST(3,2) = 15 ; LIST(4,2) = 17

! . Activate the trajectory.
CALL DCD_INITIALIZE ( TRAJECTORY )
CALL DCD_ACTIVATE_READ ( "bALA1.traj", TRAJECTORY )

! . Get the number of frames in the trajectory.
NFRAMES = TRAJECTORY%NFRAMES

! . Allocate some temporary space.
ALLOCATE ( VALUES(1:2,1:NFRAMES) )

! . Loop over the frames in the trajectory.
DO I = 1,NFRAMES

   ! . Read in the frame.
   CALL DCD_READ ( TRAJECTORY, ATMCRD )

   ! . Calculate the phi and psi dihedral angles for the structure.
   VALUES(1:2,I) = GEOMETRY_DIHEDRALS ( ATMCRD, LIST )

END DO

! . Deactivate the trajectory.
CALL DCD_DEACTIVATE ( TRAJECTORY )

! . Write out the calculated dihedrals.
WRITE ( OUTPUT, "(/A)" ) "Calculated Dihedral Angles:"
WRITE ( OUTPUT, "(/5X,A,2(7X,A))" ) "Frame", "Phi", "Psi"
WRITE ( OUTPUT, "(I10,2F10.2)" ) ( I, VALUES(1:2,I), I = 1,NFRAMES )

! . Write out the averages and RMS deviations for each dihedral.
AVERAGE =        SUM ( VALUES(1,1:NFRAMES)    ) / REAL ( NFRAMES, DP )
RMSDEV  = SQRT ( SUM ( VALUES(1,1:NFRAMES)**2 ) / REAL ( NFRAMES, DP ) - AVERAGE * AVERAGE )
WRITE ( OUTPUT, "(/A,F10.2)" ) "Phi: Average       = ", AVERAGE
WRITE ( OUTPUT,  "(A,F10.2)" ) "     RMS Deviation = ", RMSDEV

AVERAGE =        SUM ( VALUES(2,1:NFRAMES)    ) / REAL ( NFRAMES, DP )
RMSDEV  = SQRT ( SUM ( VALUES(2,1:NFRAMES)**2 ) / REAL ( NFRAMES, DP ) - AVERAGE * AVERAGE )
WRITE ( OUTPUT, "(/A,F10.2)" ) "Psi: Average       = ", AVERAGE
WRITE ( OUTPUT,  "(A,F10.2)" ) "     RMS Deviation = ", RMSDEV

! . Deallocate the temporary space.
DEALLOCATE ( VALUES )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE13
