!----------------
PROGRAM EXAMPLE15
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local parameters.
INTEGER,            PARAMETER :: NCALC  = 40
REAL ( KIND = DP ), PARAMETER :: BUFFER = 4.0_DP

! . Local scalars.
INTEGER            :: I
REAL ( KIND = DP ) :: CUT = 0.0_DP

! . Local arrays.
REAL ( KIND = DP ), DIMENSION(1:NCALC) :: CUTOFF, ENERGY_EL, ENERGY_LJ

! . Print out the header.
CALL DYNAMO_HEADER

! . Process the MM file.
CALL MM_FILE_PROCESS ( "protein.opls_bin", "../data/protein.opls" )

! . Construct the system file.
CALL MM_SYSTEM_CONSTRUCT ( "protein.opls_bin", "../data/crambin.seq" )

! . Read in some coordinates for crambin.
CALL COORDINATES_READ ( "../data/crambin.crd" )

! . Calculate and print an initial energy.
CALL ENERGY

! . Loop over the number of energy calculations.
DO I = 1,NCALC

   ! . Increment CUT.
   CUT = CUT + 1.0_DP

   ! . Set the cutoff value.
   CALL ENERGY_NON_BONDING_OPTIONS ( LIST_CUTOFF = CUT + BUFFER, OUTER_CUTOFF = CUT + BUFFER, INNER_CUTOFF = CUT, PRINT = .TRUE. )

   ! . Calculate and print the energy.
   CALL ENERGY

   ! . Save the inner cutoff value.
   CUTOFF(I) = CUT

   ! . Save the energy values.
   ENERGY_EL(I) = EELECT
   ENERGY_LJ(I) = ELJ

END DO

! . Write out the results.
WRITE ( OUTPUT, "(/8X,A,6X,A,9X,A)" ) "Inner Cutoff", "Energy - Elec.", "Energy - LJ"
WRITE ( OUTPUT, "(F20.1,2F20.4)" ) ( CUTOFF(I), ENERGY_EL(I), ENERGY_LJ(I), I = 1,NCALC )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE15
