!----------------
PROGRAM EXAMPLE16
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Print out the header.
CALL DYNAMO_HEADER

! . Process the MM file for water.
CALL MM_FILE_PROCESS ( "solvent.opls_bin", "../data/solvent.opls" )

! . Construct the system file for water.
CALL MM_SYSTEM_CONSTRUCT ( "solvent.opls_bin", "../data/h2o_box729.seq" )

! . Write out the system file.
CALL MM_SYSTEM_WRITE ( "h2o_box729.sys_bin" )

! . Read in the coordinates.
CALL COORDINATES_READ ( "../data/h2o_box729.crd" )

! . Initialize the non-bonded list cutoff options.
CALL ENERGY_NON_BONDING_OPTIONS ( LIST_CUTOFF = 13.5_DP, OUTER_CUTOFF = 12.0_DP, INNER_CUTOFF = 8.0_DP, MINIMUM_IMAGE = .TRUE. )

! . Calculate an energy.
CALL ENERGY

! . Initialize the random number seed.
CALL RANDOM_INITIALIZE ( 621815, 621816 )

! . Assign velocities to the atoms at a temperature of 300K.
CALL VELOCITY_ASSIGN ( 300.0_DP )

! . Equilibrate the system at 300K for 1 ps.
CALL DYNAMICS_OPTIONS ( 0.001_DP, 1000, 500 )
CALL VELOCITY_VERLET_DYNAMICS ( TARGET_TEMPERATURE = 300.0_DP, SCALE_FREQUENCY = 50, SCALE_OPTION = "CONSTANT" )

! . Run dynamics for 10 ps using the old velocities.
CALL DYNAMICS_OPTIONS ( 0.001_DP, 10000, 500, SAVE_FREQUENCY = 50, COORDINATE_FILE = "h2o_box729.traj" )
CALL VELOCITY_VERLET_DYNAMICS

! . Print some statistics about the non-bond energy calculation.
CALL ENERGY_NON_BONDING_STATISTICS

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE16
