!----------------
PROGRAM EXAMPLE18
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Print out the header.
CALL DYNAMO_HEADER

! . Read in the system file.
CALL MM_SYSTEM_READ ( "h2o_box729.sys_bin" )

! . Read in the coordinates.
CALL COORDINATES_READ ( "../data/h2o_box729.crd" )

! . Initialize the non-bonded list cutoff options.
CALL ENERGY_NON_BONDING_OPTIONS ( LIST_CUTOFF = 13.5_DP, OUTER_CUTOFF = 12.0_DP, INNER_CUTOFF = 8.0_DP, MINIMUM_IMAGE = .TRUE. )

! . Calculate an energy.
CALL ENERGY

! . Initialize the random number seed.
CALL RANDOM_INITIALIZE ( 314159 )

! . Assign velocities to the atoms at a temperature of 300K.
CALL VELOCITY_ASSIGN ( 300.0_DP )

! . Equilibrate the system at 300K for 1 ps.
CALL DYNAMICS_OPTIONS ( 0.001_DP, 1000, 10 )
CALL LEAPFROG_VERLET_DYNAMICS ( TARGET_TEMPERATURE  = 300.0_DP, TEMPERATURE_COUPLING = 0.1_DP, &
                                TARGET_PRESSURE     =   1.0_DP, PRESSURE_COUPLING    = 2.0E+3_DP )

! . Run dynamics for 10 ps using the old velocities.
CALL DYNAMICS_OPTIONS ( 0.001_DP, 10000, 10, SAVE_FREQUENCY = 50, COORDINATE_FILE = "h2o_box729_cpt.traj" )
CALL LEAPFROG_VERLET_DYNAMICS ( TARGET_TEMPERATURE  = 300.0_DP, TEMPERATURE_COUPLING = 0.1_DP, &
                                TARGET_PRESSURE     =   1.0_DP, PRESSURE_COUPLING    = 2.0E+3_DP )

! . Print some statistics about the non-bond energy calculation.
CALL ENERGY_NON_BONDING_STATISTICS

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE18
