!----------------
PROGRAM EXAMPLE19
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local parameters.
INTEGER,            PARAMETER :: NWINDOWS  = 5
REAL ( KIND = DP ), PARAMETER :: INCREMENT = 1.0_DP, MINIMUM = 1.5_DP

! . Local scalars.
CHARACTER ( LEN = 1 ) :: ISTRING
INTEGER               :: I
REAL ( KIND = DP )    :: DISTANCE

! . Print out the header.
CALL DYNAMO_HEADER

! . Read in the system file.
CALL MM_SYSTEM_READ ( "bALA.sys_bin" )

! . Read the coordinates.
CALL COORDINATES_READ ( "../data/bALA.crd_1pt5" )

! . Loop over the values of the distance.
DO I = 1,NWINDOWS

   ! . Initialize the random number seed.
   CALL RANDOM_INITIALIZE ( 681751 + I )

   ! . Calculate the distance.
   DISTANCE = INCREMENT * REAL ( I-1, DP ) + MINIMUM

   ! . Encode I as a string.
   CALL ENCODE_INTEGER ( I, ISTRING, "(I1)" )

   ! . Define the points for the umbrella potential.
   CALL CONSTRAINT_POINT_DEFINE ( ATOM_SELECTION ( ATOM_NUMBER = (/  6 /) ) )
   CALL CONSTRAINT_POINT_DEFINE ( ATOM_SELECTION ( ATOM_NUMBER = (/ 18 /) ) )

   ! . Define the umbrella potential.
   CALL CONSTRAINT_INITIALIZE
   CALL CONSTRAINT_DEFINE ( "DISTANCE", 20.0_DP, DISTANCE, FILE =  "bALA.window"//TRIM ( ISTRING ) )

   ! . Assign the velocities to the system at 300K.
   CALL VELOCITY_ASSIGN ( 300.0_DP, REMOVE_TRANSLATION = .FALSE. )

   ! . Equilibrate the system for 50 ps.
   CALL DYNAMICS_OPTIONS ( 0.001_DP, 50000, 1000 )
   CALL LANGEVIN_VERLET_DYNAMICS ( 300.0_DP, 25.0_DP )

   ! . Start writing.
   CALL CONSTRAINT_WRITING_START

   ! . Collect data for 100 ps.
   CALL DYNAMICS_OPTIONS ( 0.001_DP, 100000, 1000 )
   CALL LANGEVIN_VERLET_DYNAMICS ( 300.0_DP, 25.0_DP )

   ! . Stop writing.
   CALL CONSTRAINT_WRITING_STOP

END DO

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE19
