!---------------
PROGRAM EXAMPLE2
!---------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local scalars.
INTEGER            :: I, J
REAL ( KIND = DP ) :: BUFFER

! . Local array declarations.
INTEGER,              DIMENSION(:,:), POINTER :: LISTA, LISTB, LISTD
REAL ( KIND = DP ), ALLOCATABLE, DIMENSION(:) :: DATAA, DATAB, DATAD

! . Print out the header.
CALL DYNAMO_HEADER

! . Define the system.
CALL COORDINATES_DEFINE ( "../data/bALA1.crd" )

! . Generate a series of bond connectivity lists with different buffer sizes.
DO I = 0,10

   ! . Calculate BUFFER.
   BUFFER = 0.1_DP * REAL ( I, DP )

   ! . Calculate the lists.
   CALL CONNECTIVITY_BONDS ( LISTB, BUFFER )

   ! . Free the bond lists.
   DEALLOCATE ( LISTB )

END DO

! . Calculate the bond connectivity lists with a compromise buffer size.
CALL CONNECTIVITY_BONDS ( LISTB, 0.5_DP )

! . Calculate the angle and dihedral lists.
CALL CONNECTIVITY_ANGLES    ( LISTA, LISTB )
CALL CONNECTIVITY_DIHEDRALS ( LISTD, LISTB, LISTA )

! . Allocate the arrays to hold the calculated values of the internal coordinates.
ALLOCATE ( DATAA(SIZE(LISTA,2)), DATAB(SIZE(LISTB,2)), DATAD(SIZE(LISTD,2)) )

! . Calculate the internal coordinates.
DATAB = GEOMETRY_DISTANCES ( ATMCRD, LISTB )
DATAA = GEOMETRY_ANGLES    ( ATMCRD, LISTA )
DATAD = GEOMETRY_DIHEDRALS ( ATMCRD, LISTD )

! . Print the calculated values.
WRITE ( OUTPUT, "(/,A,/)" ) "Bond Lengths (Angstroms):"
WRITE ( OUTPUT, "(4(4X,2I4,2X,F6.3))" ) ( ( LISTB(J,I), J = 1,2 ), DATAB(I), I = 1,SIZE(DATAB) )

WRITE ( OUTPUT, "(/,A,/)" ) "Angles (Degrees):"
WRITE ( OUTPUT, "(3(4X,3I4,2X,F6.1))" ) ( ( LISTA(J,I), J = 1,3 ), DATAA(I), I = 1,SIZE(DATAA) )

WRITE ( OUTPUT, "(/,A,/)" ) "Dihedrals (Degrees):"
WRITE ( OUTPUT, "(3(4X,4I4,2X,F6.1))" ) ( ( LISTD(J,I), J = 1,4 ), DATAD(I), I = 1,SIZE(DATAD) )

! . Deallocate all arrays.
DEALLOCATE ( DATAA, DATAB, DATAD, LISTA, LISTB, LISTD )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE2
