!----------------
PROGRAM EXAMPLE25
!----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local parameters.
REAL ( KIND = DP ), PARAMETER :: BUFFER = 2.8_DP

! . Local scalars.
INTEGER :: I, IRES, NSATOMS, NSRESID, O

! . Local arrays.
LOGICAL, ALLOCATABLE, DIMENSION(:) :: FLAG

! . Print out the header.
CALL DYNAMO_HEADER

! . Read in the system file for the solute.
CALL MM_SYSTEM_READ ( "bALA.sys_bin" )

! . Save the number of solute atoms and residues.
NSATOMS = NATOMS
NSRESID = NRESID

! . Append the system file for the box of waters.
CALL MM_SYSTEM_APPEND ( "h2o_box729.sys_bin" )

! . Allocate the FLAG array and select the solute atoms.
ALLOCATE ( FLAG(1:NATOMS) ) ; FLAG = .FALSE. ; FLAG(1:NSATOMS) = .TRUE.

! . Read in the coordinates of the bALA.
CALL COORDINATES_READ ( "../data/bALA1.crd", SELECTION = FLAG )

! . Read in the coordinates of the waters.
CALL COORDINATES_READ ( "../data/h2o_box729.crd", SELECTION = .NOT. FLAG )

! . Transform the bALA coordinates to their principal axes.
CALL TO_PRINCIPAL_AXES ( ATMCRD(1:3,1:NSATOMS), ATMMAS(1:NSATOMS) )

! . Translate the water box so that its center of mass is at the origin.
CALL TRANSLATE_TO_CENTER ( ATMCRD(1:3,NSATOMS+1:NATOMS), ATMMAS(NSATOMS+1:NATOMS) )

! . Reinitialize the FLAG array.
FLAG = .FALSE.

! . Loop over the solvent residues.
DO IRES = (NSRESID+1),NRESID

   ! . Find the oxygen in the residue.
   O = RESIND(IRES)+1

   ! . Find the minimum distance to the non-hydrogen solute atoms.
   DO I = 1,NSATOMS
      IF ( ATMNUM(I) /= 1 ) THEN
         IF ( SUM ( ( ATMCRD(1:3,I) - ATMCRD(1:3,O) )**2 ) <= BUFFER**2 ) THEN
            FLAG(RESIND(IRES)+1:RESIND(IRES+1)) = .TRUE. ; EXIT
         END IF
      END IF
   END DO

END DO

! . Remove the flagged atoms.
CALL MM_SYSTEM_DELETE ( FLAG )

! . Save the system file.
CALL MM_SYSTEM_WRITE ( "bALAh2o_box729.sys_bin" )

! . Save the coordinates.
CALL COORDINATES_WRITE ( "bALAh2o_box729.crd1" )

! . Deallocate temporary arrays.
DEALLOCATE ( FLAG )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE25
