!---------------
PROGRAM EXAMPLE3
!---------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local array declarations.
REAL ( KIND = DP ),              DIMENSION(1:6) :: INERTIA
REAL ( KIND = DP ), ALLOCATABLE, DIMENSION(:,:) :: TMPCRD

! . Print out the header.
CALL DYNAMO_HEADER

! . Define the atom and sequence data structures.
CALL COORDINATES_DEFINE ( "../data/bALA1.crd" )

! . Move the structure to its center of mass.
CALL TRANSLATE_TO_CENTER ( ATMCRD, ATMMAS )

! . Calculate and print the inertia matrix.
INERTIA = INERTIA_MATRIX ( ATMCRD, ATMMAS )
CALL PRINT_SYMMETRIC_MATRIX ( INERTIA, "Inertia Matrix Before Reorientation:" )

! . Transform the coordinates to their principal axes.
CALL TO_PRINCIPAL_AXES ( ATMCRD, ATMMAS )

! . Calculate and print the inertia matrix in the new orientation
INERTIA = INERTIA_MATRIX ( ATMCRD, ATMMAS )
CALL PRINT_SYMMETRIC_MATRIX ( INERTIA, "Inertia Matrix After Reorientation:" )

! . Allocate a temporary coordinate array.
ALLOCATE ( TMPCRD(1:3,1:NATOMS) )

! . Read in the second set of coordinates.
CALL COORDINATES_READ ( "../data/bALA2.crd", TMPCRD )

! . Calculate the RMS coordinate deviation between the two structures.
CALL RMS_DEVIATION ( ATMCRD, TMPCRD, ATMMAS )

! . Superimpose the two structures.
CALL SUPERIMPOSE_KABSCH ( ATMCRD, TMPCRD, ATMMAS )

! . Recalculate the RMS coordinate deviation between the two structures.
CALL RMS_DEVIATION ( ATMCRD, TMPCRD, ATMMAS )

! . Deallocate the temporary coordinate array.
DEALLOCATE ( TMPCRD )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE3
