!---------------
PROGRAM EXAMPLE5
!---------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local scalars.
REAL ( KIND = DP ) :: E1, E2

! . Local arrays.
REAL ( KIND = DP ), ALLOCATABLE, DIMENSION(:)   :: HESSIAN_ANALYTIC, HESSIAN_NUMERIC
REAL ( KIND = DP ), ALLOCATABLE, DIMENSION(:,:) :: GRADIENT_ANALYTIC, GRADIENT_NUMERIC

! . Print out the header.
CALL DYNAMO_HEADER

! . Read in the system file.
CALL MM_SYSTEM_READ ( "bALA.sys_bin" )

! . Allocate space for the derivative arrays.
ALLOCATE ( GRADIENT_ANALYTIC(1:3,1:NATOMS), GRADIENT_NUMERIC(1:3,1:NATOMS) )

! . Read in a first set of coordinates.
CALL COORDINATES_READ ( "../data/bALA1.crd" )

! . Calculate and print an energy.
CALL ENERGY ; E1 = ETOTAL

! . Read in a second set of coordinates.
CALL COORDINATES_READ ( "../data/bALA2.crd" )

! . Calculate the energy and gradients for the second structure.
CALL GRADIENT ; E2 = ETOTAL ; GRADIENT_ANALYTIC = ATMDER

! . Print out the difference in the energies.
WRITE ( OUTPUT, "(/A,F12.4)" ) "Energy difference = ", E1 - E2

! . Calculate the gradients numerically for the second structure.
CALL NUMERICAL_GRADIENT ( 0.0001_DP, GRADIENT_NUMERIC )

! . Print out the largest difference.
WRITE ( OUTPUT, "(/A,G20.6)" ) "Largest gradient difference = ", &
                               MAXVAL ( ABS ( GRADIENT_ANALYTIC - GRADIENT_NUMERIC ) )

! . Deallocate the arrays.
DEALLOCATE ( GRADIENT_ANALYTIC, GRADIENT_NUMERIC )

! . Calculate an analytic Hessian without printing the energy again.
CALL HESSIAN ( PRINT = .FALSE. )

! . Allocate space for the Hessian arrays.
ALLOCATE ( HESSIAN_ANALYTIC(1:SIZE(ATMHES)), HESSIAN_NUMERIC(1:SIZE(ATMHES)) )

! . Save the analytic Hessian.
HESSIAN_ANALYTIC = ATMHES

! . Caalculate the Hessian numerically for the second structure.
CALL NUMERICAL_HESSIAN ( 0.0001_DP, HESSIAN_NUMERIC )

! . Print out the largest difference.
WRITE ( OUTPUT, "(/A,G20.6)" ) "Largest Hessian difference  = ", &
                               MAXVAL ( ABS ( HESSIAN_ANALYTIC - HESSIAN_NUMERIC ) )

! . Deallocate the arrays.
DEALLOCATE ( HESSIAN_ANALYTIC, HESSIAN_NUMERIC )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE5
