!---------------
PROGRAM EXAMPLE7
!---------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local scalars.
REAL ( KIND = DP ) :: ESTART, ESTOP

! . Print out the header.
CALL DYNAMO_HEADER

! . Process the MM file for cyclohexane.
CALL MM_FILE_PROCESS ( "cyclohexane.opls_bin", "../data/cyclohexane.opls" )

! . Construct the system file for cyclohexane.
CALL MM_SYSTEM_CONSTRUCT ( "cyclohexane.opls_bin", "../data/cyclohexane.seq" )

! . Save the system file for cyclohexane for later use.
CALL MM_SYSTEM_WRITE ( "cyclohexane.sys_bin" )

! . Read in the coordinates.
CALL COORDINATES_READ ( "../data/cyclohexane_chair.crd" )

! . Calculate and print the initial energy.
CALL ENERGY ; ESTART = ETOTAL

! . Perform a coordinate minimization.
CALL OPTIMIZE_BAKER ( "SADDLE", FOLLOW_MODE =   1, MAXIMUM_STEP = 0.1_DP,  PRINT_FREQUENCY = 1, &
                                STEP_NUMBER = 200, GRADIENT_TOLERANCE = 1.0E-6_DP )

! . Calculate and print the final energy.
CALL ENERGY ; ESTOP = ETOTAL

! . Print the energy change.
WRITE ( OUTPUT, "(/A,F20.4)" ) "Energy change after the search = ", ESTOP - ESTART

! . Write out the coordinates.
CALL COORDINATES_WRITE ( "../data/cyclohexane_saddle.crd" )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM EXAMPLE7
