!------------------
PROGRAM NEBEXAMPLE1
!------------------
!
! . This example illustrates how to use the NEB method. The commands are
! . very similar to those of the SAW module used in Example 9.
!

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Local arrays.
REAL ( KIND = DP ), ALLOCATABLE, DIMENSION(:,:) :: REACTANTS, PRODUCTS

! . Print out the header.
CALL DYNAMO_HEADER

! . Construct the system file for cyclohexane.
CALL MM_SYSTEM_READ ( "cyclohexane.sys_bin" )

! . Allocate space for the arrays.
ALLOCATE ( REACTANTS(1:3,1:NATOMS), PRODUCTS(1:3,1:NATOMS) )

! . Read in the coordinates of the chair form.
CALL COORDINATES_READ ( "../data/cyclohexane_chair.crd" )

! . Save the reactant coordinates.
REACTANTS = ATMCRD

! . Read in the coordinates of the boat form.
CALL COORDINATES_READ ( "../data/cyclohexane_boat.crd" )

! . Save the product coordinates.
PRODUCTS = ATMCRD

! . Initialize a chain trajectory.
CALL GROWING_STRING ( "cyclohexane1.neb", 21, REACTANTS, PRODUCTS )

! . Optimize the chain.
CALL NEB_OPTIMIZE_SPLINE ( "cyclohexane1.neb", "cyclohexane2.neb", PRINT_FREQUENCY = 1, STEP_NUMBER = 5000, &
                           STEP_SIZE = 1.0_DP, GRADIENT_TOLERANCE = 0.02_DP, NBINS = 50 )

! . Deallocate the temporary space.
DEALLOCATE ( REACTANTS, PRODUCTS )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM NEBEXAMPLE1
