!-----------------
PROGRAM QMEXAMPLE2
!-----------------

! . Module declarations.
USE DYNAMO

IMPLICIT NONE

! . Parameters.
INTEGER :: NBEADS = 32, NPIPARTICLES = 6

! . Scalars.
INTEGER :: I, II, J

! . Arrays.
INTEGER, ALLOCATABLE, DIMENSION(:,:) :: PIFLAG

! . Print out the header.
CALL DYNAMO_HEADER

! . Define the system by reading in a set of coordinates.
CALL XYZ_DEFINE ( "../data/ch5_pi.xyz" )

! . Set up the PIFLAG array.
ALLOCATE ( PIFLAG(1:NPIPARTICLES,1:NBEADS) )
II = 0
DO I = 1,NBEADS
   DO J = 1,NPIPARTICLES
      II = II + 1
      PIFLAG(J,I) = II
   END DO
END DO

! . Define all the atoms to be AM1.
CALL MOPAC_SETUP ( "AM1", CHARGE = 1, PIATOMS = PIFLAG, PITEMPERATURE = 5.0_DP )

! . Deallocate PIFLAG.
DEALLOCATE ( PIFLAG )

! . Calculate and print an energy.
CALL ENERGY

! . Initialize the random number seed.
CALL RANDOM_INITIALIZE ( 656171, 656172 )

! . Assign velocities to the atoms at a temperature of 5 K.
CALL VELOCITY_ASSIGN ( 5.0_DP, REMOVE_TRANSLATION = .FALSE. )

! . Equilibrate the system.
CALL DYNAMICS_OPTIONS ( 1.0E-4_DP, 1000, 100 )
CALL LANGEVIN_VERLET_DYNAMICS ( 5.0_DP, 100.0_DP )

! . Run the dynamics.
CALL DYNAMICS_OPTIONS ( 1.0E-4_DP, 1000, 100, SAVE_FREQUENCY = 100, COORDINATE_FILE = "ch5_pi_dyn1.traj" )
CALL LANGEVIN_VERLET_DYNAMICS ( 5.0_DP, 100.0_DP )

! . Save the coordinates.
CALL XYZ_WRITE ( "ch5_pi_dyn1.xyz" )

! . Finish up.
CALL DYNAMO_FOOTER

END PROGRAM QMEXAMPLE2
