#! /bin/csh -f
################################################################################
#                      DYNAMO Installation Script Version 2
################################################################################
#
# . Compiler/machine types:
#
#   alpha                         Alpha processors.
#   gfortran                      GNU gfortran
#   g95                           g95 fortran.
#   intel                         Intel Linux.
#   nagpc95                       NAG compiler for PC/Linux.
#   pgpc                          Portland Group compiler for PC/Linux.
#   pgpc_acml                     Portland Group compiler for PC/Linux with
#                                 ACML math library from AMD.
# . Notes:
#
#   Modified in August 2005 for the release of version 2.3.
#
#   gfortran and g95 do not work at present (compiler errors).
#
################################################################################

#-------------------------------------------------------------------------------
# . Get the argument specifying the compiler and machine type.

if ( $#argv == 0 ) then

   echo "------------------------------------"
   echo "Compiler/machine type not specified."
   echo "------------------------------------"
   echo " "
   echo "Choose among alpha, gfortran, g95, intel, nagpc95, pgpc, pgpc_acml."
   exit

else if ( $#argv == 1 ) then

   set compiler = $argv[1]
   echo " "

else

   echo "-------------------"
   echo "Too many arguments."
   echo "-------------------"
   exit

endif

#-------------------------------------------------------------------------------
# . Check the input arguments.

switch ( $compiler )
case alpha:
   echo "Installing DYNAMO for an Alpha system."
   breaksw
case gfortran:
   echo "Installing DYNAMO for a GNU gfortran/Linux system."
   breaksw
case g95:
   echo "Installing DYNAMO for a g95/Linux system."
   breaksw
case intel:
   echo "Installing DYNAMO for a Intel/Linux system."
   breaksw
case nagpc95:
   echo "Installing DYNAMO for a NAG/Linux Fortran 95 system."
   breaksw
case nagpc95d:
   echo "Installing DYNAMO for a NAG/Linux Fortran 95 system with debug flags."
   breaksw
case pgpc:
   echo "Installing DYNAMO for a Portland Group Compiler/Linux system."
   breaksw
case pgpc_acml:
   echo "Installing DYNAMO for a Portland Group Compiler/Linux system with the ACML math library from AMD."
   breaksw
default:
   echo "Unknown compiler/machine type specified."
   exit
   breaksw
endsw

#-------------------------------------------------------------------------------
# . Set up some environment variables.

setenv DYNAMO_V2PT2 `pwd`

#-------------------------------------------------------------------------------
# . Copy the machine-dependent files to their appropriate positions.

cd $DYNAMO_V2PT2/machines

cp compile.com_$compiler     ../compile.com
cp interactive.com_$compiler ../interactive.com
cp Makefile_$compiler        ../Makefile
cp run.com_$compiler         ../run.com

#-------------------------------------------------------------------------------
# . Now build the library.

cd $DYNAMO_V2PT2

make library

#-------------------------------------------------------------------------------
# . Finish up.

exit
